Requirements notes:
==================
arrow: will manage all datetime functionality
requests: will be used to fetch data from rest urls.


Expected format:
==============

Usable by reports scripts:

        {'client_name':
            { 'b_last'    : 'iso8601',
              'b_state'    : 'working/current',
              'b_phase' : 'phase1/phase2',
              'b_date' : 'date',
              'b_time' : 'time',
              'server' : ['server',  'list', 'in multi-agent mode']
            }
        }

*b_last:* will use http://crsmithdev.com/arrow/#arrow.arrow.Arrow.isoformat - As described in https://git.ziirish.me/ziirish/burp-ui/issues/146#note_1306
*b_date and b_time* will be converted to local time always. (It simplifies the txt module)
*server:* Is additionally added when found from api backend, it appears when the burpui is in multi-agent mode.

#### Generated by clients_reports.report_outdated:

    {'client_name':
        { --- ommited values ---,
          'b_status: 'outdated'
        }
    }

#### Required for --detail:

    {'client_name':
        { --- ommited values ---,
          'backup_report': {
              'duration': seconds
              'totsize': bytes
              'received': bytes
          }
        }
    }

#### More information that will be processed later:

{'client_name':
        { 'b_number'  : 'number',
          'b_date'    : 'date',
          'b_status'  : 'outdated/ok',
          # 'b_type'    : 'finishing/working/current',
          'quota'   : 'ok/soft/hard',
          'warnings': 'warnings',
          'exclude' : 'yes/no',
          'b_phase' : 'phase1/phase2',
          'b_phase_date' : 'date',
          'b_phase_status' : 'outdated/ok',
          'b_curr_taken' : 'seconds',
          'backup_stats' : {'contents': 'all contents of backup_stats file for the client', some example:
                            'time_taken': 'seconds', 'bytes_in_backup': 'bytes', bytes_received: 'bytes'}
        }
}


Testing with burpui demo server
==============================

    burp-reports --debug --burpui_apiurl https://admin:admin@demo.ziirish.me/api/ --report outdated --detail
    burp-reports --debug --burpui_apiurl https://admin:admin@demo.ziirish.me/api/ --detail
    burp-reports --burpui_apiurl https://admin:admin@demo.ziirish.me/api/

Or with conf:

    burp-reports -c ~/burp-reports.conf --debug --burpui_apiurl https://admin:admin@demo.ziirish.me/api/ --report outdated --detail


